@@ -4,5 +4,6 @@
 
 utils::globalVariables(c(
   ".", "contour", "lat", "layer_area", "lon", "name",
-  "roundabout_exits", "waypoint_index", "x", "y"
+  "roundabout_exits", "waypoint_index", "x", "y",
+  "origins", "ix"
 ))
